@@ -95,7 +95,7 @@ impl MpScBytesQueue {
             .zip(uninit_slices.iter_mut())
             .for_each(|(bytes, uninit_slice)| {
                 // Every bytes is non-empty, so every io_slice created is non-empty.
-                uninit_slice.write(IoSlice::new(bytes));
+                *uninit_slice = MaybeUninit::new(IoSlice::new(bytes));
             });
 
         Some(Buffers {
@@ -130,7 +130,7 @@ impl QueuePusher<'_> {
 
     pub fn extend<const N: usize>(&mut self, bytes_array: [Bytes; N]) {
         self.0.reserve_exact(N);
-        self.extend_impl(bytes_array);
+        self.extend_impl(bytes_array.iter().cloned());
     }
 
     pub fn extend_from_iter(&mut self, iter: impl IntoIterator<Item = Bytes>) {
